@@ -3,7 +3,7 @@ package ColorTheme::Test::Random;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-01'; # DATE
 our $DIST = 'ColorThemes-Test'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -32,7 +32,7 @@ our %THEME = (
 sub list_items {
     my $self = shift;
 
-    my @list = [0 .. ($self->{args}{num}//5)-1];
+    my @list = 0 .. ($self->{args}{num}//5)-1;
     wantarray ? @list : \@list;
 }
 
@@ -61,7 +61,7 @@ ColorTheme::Test::Random - A color theme which gives random colors
 
 =head1 VERSION
 
-This document describes version 0.004 of ColorTheme::Test::Random (from Perl distribution ColorThemes-Test), released on 2021-08-01.
+This document describes version 0.005 of ColorTheme::Test::Random (from Perl distribution ColorThemes-Test), released on 2021-08-01.
 
 =head1 HOMEPAGE
 
