@@ -3,7 +3,7 @@ package ColorTheme::Test::RandomANSI16;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-01'; # DATE
 our $DIST = 'ColorThemes-Test'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -34,7 +34,7 @@ sub _rand_ansi16 {
 sub list_items {
     my $self = shift;
 
-    my @list = [0 .. ($self->{args}{num}//5)-1];
+    my @list = 0 .. ($self->{args}{num}//5)-1;
     wantarray ? @list : \@list;
 }
 
@@ -63,7 +63,7 @@ ColorTheme::Test::RandomANSI16 - A color theme which gives random 16-color ANSI
 
 =head1 VERSION
 
-This document describes version 0.004 of ColorTheme::Test::RandomANSI16 (from Perl distribution ColorThemes-Test), released on 2021-08-01.
+This document describes version 0.005 of ColorTheme::Test::RandomANSI16 (from Perl distribution ColorThemes-Test), released on 2021-08-01.
 
 =head1 HOMEPAGE
 
